#!/bin/sh
#-----------------------------------------------------------------------
# Licensed Materials - Property of IBM
#
# IBM Tape System Library Manager
#
# (C) Copyright IBM Corp. 2004, 2020 All Rights Reserved
#
# US Government Users Restricted Rights - Use,  duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#-----------------------------------------------------------------------
#
# @version 1.7 - 16/06/19 22:54:53
#
# @brief
#
#  The following three lines have been added by UDB DB2.
#
#-----------------------------------------------------------------------

if [ ! -e ~/tslmprofile ]; then
    echo "This script must be run with TSLM user account. ('ermm' for example)"
    exit 1
fi

echo "IBM Tape System Library Manager"
echo "Licensed Materials - Property of IBM"
echo "(C) Copyright IBM Corp. 2004, 2020 All Rights Reserved"
echo


# This script must run by ermm user
if [ "$USER" != "$TSLM_USER" ]; then
    echo "This script must be run with $TSLM_USER account."
    exit 1
fi


# Log file for this script 
LOG=$TSLM_BASEDIR/log/tslmdbrestore.log

# Get definitions of backup setting
. $TSLM_BASEDIR/conf/dbuserexit.conf

# TSLMDBBACKUPDIR has the directory name for the backup files 
# check existence TSLMDBBACKUPDIR directory
if [ ! -d $TSLMDBBACKUPDIR ]
then
    echo "Backup directory $TSLMDBBACKUPDIR is not fonud." 
    exit 2
fi

# check if the Media Manager is running 
MMRUN=$(ps -ef | awk '{print $8}' | grep "^$TSLM_BASEDIR/bin/MediaManager" )
if [ ! -z "$MMRUN" ]
then
    echo "Stop the Media Manager before the restore." 
    exit 2
fi


if [ -f $INSTHOME/sqllib/db2profile ]; then
    . $INSTHOME/sqllib/db2profile
fi

TIMESTAMP=$1

echo "Backup Files:"
ls -l $TSLMDBBACKUPDIR

echo "Check the existence of ermm database" | tee $LOG
db2 "connect to ermm" >> $LOG 2>&1
if [ $? != 0 ];
then
   if [ "${TIMESTAMP}" != "" ]; then
       echo "Start restoring the database. (${TIMESTAMP})" | tee -a $LOG
       db2 "restore database ermm from $TSLMDBBACKUPDIR taken at ${TIMESTAMP}" | tee -a $LOG 2>&1
   else
       echo "Start restoring the database." | tee -a $LOG
       db2 "restore database ermm from $TSLMDBBACKUPDIR" | tee -a $LOG 2>&1
   fi
   echo "Done"
   exit 0
else
   db2 "disconnect current" >> $LOG 2>&1
   echo "Caution!! Existing database ermm! Should database be dropped? (Y/N)" | tee -a $LOG
   while [ 1 ];
   do
     read char
     if [[ $char == "y" || $char == "Y" ]]; then
	 if [ "${TIMESTAMP}" != "" ]; then
	     db2 "restore database ermm from $TSLMDBBACKUPDIR taken at ${TIMESTAMP} WITHOUT PROMPTING" | tee -a $LOG 2>&1 
	     echo "Done."
	 else
	     db2 "restore database ermm from $TSLMDBBACKUPDIR WITHOUT PROMPTING" | tee -a $LOG 2>&1
	     echo "Done."
	 fi
	 exit 0
     else
       echo "Operation was interrupted by user." | tee -a $LOG
       echo "Done."
       exit 0
     fi
   done
fi
