#!/bin/sh
#-----------------------------------------------------------------------
# Licensed Materials - Property of IBM
#
# IBM Tape System Library Manager
#
# (C) Copyright IBM Corp. 2004, 2020 All Rights Reserved
#
# US Government Users Restricted Rights - Use,  duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#-----------------------------------------------------------------------
#
# @version 1.5 - 20/03/18 22:03:54
#
# @brief
#
#  The following three lines have been added by UDB DB2.
#
#-----------------------------------------------------------------------

if [ ! -e ~/tslmprofile ]; then
    echo "This script must be run with TSLM user account. ('ermm' for example)"
    exit 1
fi

echo "IBM Tape System Library Manager"
echo "Licensed Materials - Property of IBM"
echo "(C) Copyright IBM Corp. 2004, 2020 All Rights Reserved"
echo


# This script must run by ermm user
if [ "$USER" != "$TSLM_USER" ]; then
    echo "This script must be run with $TSLM_USER account."
    exit 1
fi


# Log file for this script 
LOG=$TSLM_BASEDIR/log/tslmresetlogarchive.log


# check if the Media Manager is running 
MMRUN=$(ps -ef | awk '{print $8}' | grep "^$TSLM_BASEDIR/bin/MediaManager" )
if [ ! -z "$MMRUN" ]
then
    echo "Stop the Media Manager before changing database setting" 
    exit 2
fi


#
# Update db cfg parameter mirrorlogpath
#
echo "Reset MIRRORLOGPATH parameter ..." | tee  $LOG
db2 "update db cfg for ermm using MIRRORLOGPATH NULL" | tee -a $LOG
if [ $? != 0 ]
then
    echo "Cannot update MIRRORLOGPATH parameter of database ermm." | tee -a $LOG
    exit 2
fi

#
# Update db cfg parameter logarchmeth1 select LOGRETAIN or USEREXIT
#

echo "Setting LOGARCHMETH1 off  ..." | tee -a $LOG
db2 "update db cfg for ermm using LOGARCHMETH1 off" | tee -a $LOG 2>&1 
if [ $? != 0 ]
then
    echo "Cannot update LOGARCHMETH1 to off for database ermm." | tee -a $LOG
    exit 2
fi



echo "Successfully changing the database to reset archive logging mode."
exit 0
